==> haskell-abstract-par-0.3.3-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-abstract-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 abstract-par
version:              0.3.3
visibility:           public
id:                   abstract-par-0.3.3-ISux4E1QYRJK5C39S1lmJd
key:                  abstract-par-0.3.3-ISux4E1QYRJK5C39S1lmJd
license:              BSD-3-Clause
copyright:            (c) Ryan Newton 2011-2012
maintainer:           Ryan Newton <rrnewton@gmail.com>
author:               Ryan Newton
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:
    Type classes generalizing the functionality of the '\''monad-par'\'' library.

description:
    The '\''Par'\'' monad offers a parallel programming API based on dataflow
    programming.  To use the `Par` monad, install the @monad-par@
    package, which includes this package as a dependency.

    This package is an abstract interface only. It provides a number of
    type clasess, but not an implementation.  The type classes separate
    different levels of @Par@ functionality.  See the
    "Control.Monad.Par.Class" module for more details.

category:             Control,Parallelism,Monads
abi:                  b19bc5835411f82f189880721a8ddeb8
exposed:              True
exposed-modules:      Control.Monad.Par.Class Control.Monad.Par.Unsafe
import-dirs:          /usr/lib/ghc-9.2.8/site-local/abstract-par-0.3.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/abstract-par-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-abstract-par
hs-libraries:         HSabstract-par-0.3.3-ISux4E1QYRJK5C39S1lmJd
depends:              base-4.16.4.0 deepseq-1.4.6.1
haddock-interfaces:
    /usr/share/doc/haskell-abstract-par/html/abstract-par.haddock

haddock-html:         /usr/share/doc/haskell-abstract-par/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-abstract-par-0.3.3-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-abstract-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 abstract-par
version:              0.3.3
visibility:           public
id:                   abstract-par-0.3.3-7WRIVoWpARZGuBib8Nevl1
key:                  abstract-par-0.3.3-7WRIVoWpARZGuBib8Nevl1
license:              BSD-3-Clause
copyright:            (c) Ryan Newton 2011-2012
maintainer:           Ryan Newton <rrnewton@gmail.com>
author:               Ryan Newton
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:
    Type classes generalizing the functionality of the '\''monad-par'\'' library.

description:
    The '\''Par'\'' monad offers a parallel programming API based on dataflow
    programming.  To use the `Par` monad, install the @monad-par@
    package, which includes this package as a dependency.

    This package is an abstract interface only. It provides a number of
    type clasess, but not an implementation.  The type classes separate
    different levels of @Par@ functionality.  See the
    "Control.Monad.Par.Class" module for more details.

category:             Control,Parallelism,Monads
abi:                  bbbb9c55efe812fb38b36af4d6093e54
exposed:              True
exposed-modules:      Control.Monad.Par.Class Control.Monad.Par.Unsafe
import-dirs:          /usr/lib/ghc-9.4.8/site-local/abstract-par-0.3.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/abstract-par-0.3.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/abstract-par-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-abstract-par
hs-libraries:         HSabstract-par-0.3.3-7WRIVoWpARZGuBib8Nevl1
depends:              base-4.17.2.1 deepseq-1.4.8.0
haddock-interfaces:
    /usr/share/doc/haskell-abstract-par/html/abstract-par.haddock

haddock-html:         /usr/share/doc/haskell-abstract-par/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
